@@ -8,7 +8,7 @@
 
 package Math::Polygon;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 
 use strict;
@@ -55,7 +55,12 @@ sub nrPoints() { scalar @{shift->{MP_points}} }
 sub order() { @{shift->{MP_points}} -1 }
 
 
-sub points() { wantarray ? @{shift->{MP_points}} : shift->{MP_points} }
+sub points(;$)
+{   my ($self, $format) = @_;
+	my $points = $self->{MP_points};
+	$points    = [ polygon_format $format, @$points ] if $format;
+    wantarray ? @$points : $points;
+}
 
 
 sub point(@)
@@ -268,6 +273,9 @@ sub fillClip1($$$$)
 #-------------
 
 
-sub string() { polygon_string(shift->points) }
+sub string(;$)
+{   my ($self, $format) = @_;
+    polygon_string($self->points($format));
+}
 
 1;
