@@ -8,7 +8,7 @@
 
 package Math::Polygon::Clip;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use base 'Exporter';
 
@@ -147,7 +147,7 @@ sub _cross($$$)
 
 sub _cross_inside($$$)
 {   my ($bbox, $from, $to) = @_;
-    grep { _inside($bbox, $_) } _cross($bbox, $from, $to);
+    grep _inside($bbox, $_), _cross($bbox, $from, $to);
 }
 
 sub _remove_doubles(@)
@@ -167,7 +167,6 @@ sub _cross_x($$$)
     my ($tx, $ty) = @$to;
     return () unless $fx < $x && $x < $tx || $tx < $x && $x < $fx;
     my $y = $fy + ($x - $fx)/($tx - $fx) * ($ty - $fy);
-#warn "X: $x,$y <-- $fx,$fy $tx,$ty\n";
     (($fy <= $y && $y <= $ty) || ($ty <= $y && $y <= $fy)) ? [$x,$y] : ();
 }
 
@@ -177,7 +176,6 @@ sub _cross_y($$$)
     my ($tx, $ty) = @$to;
     return () unless $fy < $y && $y < $ty || $ty < $y && $y < $fy;
     my $x = $fx + ($y - $fy)/($ty - $fy) * ($tx - $fx);
-#warn "Y: $x,$y <-- $fx,$fy $tx,$ty\n";
     (($fx <= $x && $x <= $tx) || ($tx <= $x && $x <= $fx)) ? [$x,$y] : ();
 }
 
