@@ -8,7 +8,7 @@
 
 package Math::Polygon::Transform;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use base 'Exporter';
 
@@ -258,7 +258,8 @@ sub polygon_simplify(@)
         @_ = @new;
     }
 
-    return @_ unless exists $opts{max_points};
+	exists $opts{max_points}
+        or return @_;
 
     #
     # Reduce the number of points to $max
@@ -291,7 +292,7 @@ sub polygon_simplify(@)
     }
 
     # Return left-over points
-    @_ = grep {defined} @_;
+    @_ = grep defined, @_;
     push @_, $_[0] if $is_ring;
     @_;
 }
